@@ -1,18 +1,18 @@
 package Class::Variable;
-use strict; use warnings FATAL => 'all'; 
-use parent 'Exporter';
 use 5.008;
+use strict; use warnings FATAL => 'all'; 
+use Exporter 'import';
 use Carp;
 use Scalar::Util 'weaken';
 
-our $VERSION = '1.001'; # <== update version in pod
+our $VERSION = '1.002'; # <== update version in pod
 
 our @EXPORT;
 
 my $NS = {};
 
 push @EXPORT, 'public';
-sub public
+sub public($;)
 {
     my @names = @_;
     my $package = (caller)[0];
@@ -24,7 +24,7 @@ sub public
 }
 
 push @EXPORT, 'protected';
-sub protected
+sub protected($;)
 {
     my @names = @_;
     my $package = (caller)[0];
@@ -36,7 +36,7 @@ sub protected
 }
 
 push @EXPORT, 'private';
-sub private
+sub private($;)
 {
     my @names = @_;
     my $package = (caller)[0];
@@ -89,9 +89,9 @@ sub get_protected_variable($$)
         
         croak sprintf(
             "Access violation: protected variable %s of %s available only to class or subclasses, but not %s."
-            , $name
-            , $package
-            , caller ) if not caller->isa($package);
+            , $name || 'undefined'
+            , $package || 'undefined'
+            , caller()  || 'undefined' ) if not caller()->isa($package);
             
         $NS->{$self}->{$name};
     };
@@ -117,14 +117,15 @@ sub get_private_variable($$)
         
         croak sprintf(
             "Access violation: private variable %s of %s available only to class itself, not %s."
-            , $name
-            , $package
-            , caller ) if caller ne $package;
+            , $name || 'undefined'
+            , $package || 'undefined'
+            , caller()  || 'undefined' ) if caller() ne $package;
             
         $NS->{$self}->{$name};
     };
 }
 
+
 1;
 __END__
 =head1 NAME
@@ -133,7 +134,7 @@ Class::Variable - Perl implementation of class variables with access restriction
 
 =head1 VERSION
 
-Version 1.001
+Version 1.002
 
 =head1 SYNOPSIS
 
